@@ -6,7 +6,7 @@ several values for the same key.
 """
 
 from ._abc import MultiMapping, MutableMultiMapping
-from ._compat import USE_CYTHON_EXTENSIONS
+from ._compat import USE_EXTENSIONS
 
 __all__ = (
     "MultiMapping",
@@ -20,11 +20,11 @@ __all__ = (
     "getversion",
 )
 
-__version__ = "5.0.2"
+__version__ = "6.0.1"
 
 
 try:
-    if not USE_CYTHON_EXTENSIONS:
+    if not USE_EXTENSIONS:
         raise ImportError
     from ._multidict import (
         CIMultiDict,
