@@ -7,8 +7,8 @@ import multidict
 
 
 def test_classes_not_abstract() -> None:
-    d1 = multidict.MultiDict({"a": "b"})  # type: multidict.MultiDict[str,str]
-    d2 = multidict.CIMultiDict({"a": "b"})  # type: multidict.CIMultiDict[str,str]
+    d1: multidict.MultiDict[str] = multidict.MultiDict({"a": "b"})
+    d2: multidict.CIMultiDict[str] = multidict.CIMultiDict({"a": "b"})
 
     d3 = multidict.MultiDictProxy(d1)
     d4 = multidict.CIMultiDictProxy(d2)
